# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.plans_schedule_api import PlansScheduleApi


class TestPlansScheduleApi(unittest.TestCase):
    """PlansScheduleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansScheduleApi()

    def tearDown(self) -> None:
        pass

    def test_create_plan_schedule_plan_schedule_schedule_post(self) -> None:
        """Test case for create_plan_schedule_plan_schedule_schedule_post

        Create Plan Schedule
        """
        pass

    def test_delete_plan_schedule_plan_schedule_schedule_schedule_id_delete(self) -> None:
        """Test case for delete_plan_schedule_plan_schedule_schedule_schedule_id_delete

        Delete Plan Schedule
        """
        pass

    def test_list_plan_schedules_plan_schedule_schedule_get(self) -> None:
        """Test case for list_plan_schedules_plan_schedule_schedule_get

        List Plan Schedules
        """
        pass

    def test_update_plan_schedule_plan_schedule_schedule_schedule_id_put(self) -> None:
        """Test case for update_plan_schedule_plan_schedule_schedule_schedule_id_put

        Update Plan Schedule
        """
        pass


if __name__ == "__main__":
    unittest.main()



from collections.abc import Callable, Generator, Sequence
from enum import Enum
from typing import ParamSpec, Protocol, TypeVar

from pydantic import BaseModel

import cybee_sdk.api as cybee_api
from cybee_sdk.api.models.agent_info import AgentInfo

T_co = TypeVar("T_co", bound=BaseModel, covariant=True)
P = ParamSpec("P")


class HasItems(Protocol[T_co]):
    @property
    def items(self) -> Sequence[T_co]: ...


def sizeof_fmt(num, suffix="B"):
    for unit in ("", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi"):
        if abs(num) < 1024.0:
            return f"{num:3.1f}{unit}{suffix}"
        num /= 1024.0
    return f"{num:.1f}Yi{suffix}"


def paginator(query_function: Callable[P, HasItems[T_co]], /, *args: P.args, **kwargs: P.kwargs) -> Generator[T_co]:
    page_number = 0

    while True:
        kwargs["page"] = page_number
        resp = query_function(*args, **kwargs)
        if not resp.items:
            break
        yield from resp.items

        page_number += 1

    return


def list_agents(api_configuration: cybee_api.Configuration, /, *args, **kwargs) -> Generator[AgentInfo]:
    with cybee_api.ApiClient(api_configuration) as api_client:
        agent_api = cybee_api.AgentsApi(api_client)
        yield from paginator(agent_api.list_agent_agent_get, *args, **kwargs)


class PlanKind(Enum):
    BACKUP = "backup"
    RESTORE = "restore"


class PlanMode(Enum):
    FILE = "file"
    IMAGE = "image"



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.backup_error import BackupError
from cybee_sdk.api.models.backup_fatal_error import BackupFatalError
from cybee_sdk.api.models.backup_status import BackupStatus
from cybee_sdk.api.models.backup_summary import BackupSummary
from cybee_sdk.api.models.backup_verbose_status import BackupVerboseStatus
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class BackupInfo(BaseModel):
    """
    BackupInfo
    """  # noqa: E501

    status: Optional[BackupStatus] = None
    restic_error: Optional[BackupError] = None
    restic_fatal_error: Optional[BackupFatalError] = None
    verbose_status: Optional[BackupVerboseStatus] = None
    summary: Optional[BackupSummary] = None
    unknown: Optional[StrictStr] = None
    other_error: Optional[StrictStr] = None
    backup_ended: Optional[Dict[str, Any]] = None
    backup_fully_finished: Optional[Dict[str, Any]] = None
    timestamp: StrictStr
    backup_paths: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = [
        "status",
        "restic_error",
        "restic_fatal_error",
        "verbose_status",
        "summary",
        "unknown",
        "other_error",
        "backup_ended",
        "backup_fully_finished",
        "timestamp",
        "backup_paths",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BackupInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict["status"] = self.status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of restic_error
        if self.restic_error:
            _dict["restic_error"] = self.restic_error.to_dict()
        # override the default output from pydantic by calling `to_dict()` of restic_fatal_error
        if self.restic_fatal_error:
            _dict["restic_fatal_error"] = self.restic_fatal_error.to_dict()
        # override the default output from pydantic by calling `to_dict()` of verbose_status
        if self.verbose_status:
            _dict["verbose_status"] = self.verbose_status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of summary
        if self.summary:
            _dict["summary"] = self.summary.to_dict()
        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict["status"] = None

        # set to None if restic_error (nullable) is None
        # and model_fields_set contains the field
        if self.restic_error is None and "restic_error" in self.model_fields_set:
            _dict["restic_error"] = None

        # set to None if restic_fatal_error (nullable) is None
        # and model_fields_set contains the field
        if self.restic_fatal_error is None and "restic_fatal_error" in self.model_fields_set:
            _dict["restic_fatal_error"] = None

        # set to None if verbose_status (nullable) is None
        # and model_fields_set contains the field
        if self.verbose_status is None and "verbose_status" in self.model_fields_set:
            _dict["verbose_status"] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict["summary"] = None

        # set to None if unknown (nullable) is None
        # and model_fields_set contains the field
        if self.unknown is None and "unknown" in self.model_fields_set:
            _dict["unknown"] = None

        # set to None if other_error (nullable) is None
        # and model_fields_set contains the field
        if self.other_error is None and "other_error" in self.model_fields_set:
            _dict["other_error"] = None

        # set to None if backup_ended (nullable) is None
        # and model_fields_set contains the field
        if self.backup_ended is None and "backup_ended" in self.model_fields_set:
            _dict["backup_ended"] = None

        # set to None if backup_fully_finished (nullable) is None
        # and model_fields_set contains the field
        if self.backup_fully_finished is None and "backup_fully_finished" in self.model_fields_set:
            _dict["backup_fully_finished"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BackupInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "status": BackupStatus.from_dict(obj["status"]) if obj.get("status") is not None else None,
                "restic_error": BackupError.from_dict(obj["restic_error"])
                if obj.get("restic_error") is not None
                else None,
                "restic_fatal_error": BackupFatalError.from_dict(obj["restic_fatal_error"])
                if obj.get("restic_fatal_error") is not None
                else None,
                "verbose_status": BackupVerboseStatus.from_dict(obj["verbose_status"])
                if obj.get("verbose_status") is not None
                else None,
                "summary": BackupSummary.from_dict(obj["summary"]) if obj.get("summary") is not None else None,
                "unknown": obj.get("unknown"),
                "other_error": obj.get("other_error"),
                "backup_ended": obj.get("backup_ended"),
                "backup_fully_finished": obj.get("backup_fully_finished"),
                "timestamp": obj.get("timestamp"),
                "backup_paths": obj.get("backup_paths"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.phy_cpu import PhyCpu


class TestPhyCpu(unittest.TestCase):
    """PhyCpu unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhyCpu:
        """Test PhyCpu
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PhyCpu`
        """
        model = PhyCpu()
        if include_optional:
            return PhyCpu(
                vendor = '',
                brand = '',
                architecture = '',
                cores = [
                    cybee_sdk.api.models.cores_group.CoresGroup(
                        variant = '', 
                        cores_count = 56, 
                        threads_per_core = 56, 
                        freq = 1.337, )
                    ]
            )
        else:
            return PhyCpu(
                vendor = '',
                brand = '',
                architecture = '',
                cores = [
                    cybee_sdk.api.models.cores_group.CoresGroup(
                        variant = '', 
                        cores_count = 56, 
                        threads_per_core = 56, 
                        freq = 1.337, )
                    ],
        )
        """

    def testPhyCpu(self):
        """Test PhyCpu"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.cmdb_api import CmdbApi


class TestCmdbApi(unittest.TestCase):
    """CmdbApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CmdbApi()

    def tearDown(self) -> None:
        pass

    def test_list_cmdb_items_cmdb_machines_get(self) -> None:
        """Test case for list_cmdb_items_cmdb_machines_get

        List Cmdb Items
        """
        pass

    def test_list_historical_cmdb_items_cmdb_machines_historical_get(self) -> None:
        """Test case for list_historical_cmdb_items_cmdb_machines_historical_get

        List Historical Cmdb Items
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restoration_info import RestorationInfo


class TestRestorationInfo(unittest.TestCase):
    """RestorationInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RestorationInfo:
        """Test RestorationInfo
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RestorationInfo`
        """
        model = RestorationInfo()
        if include_optional:
            return RestorationInfo(
                status = cybee_sdk.api.models.restoration_status.RestorationStatus(
                    seconds_elapsed = 56, 
                    percent_done = 1.337, 
                    total_files = 56, 
                    files_restored = 56, 
                    total_bytes = 56, 
                    bytes_restored = 56, ),
                verbose_status = cybee_sdk.api.models.restore_verbose_status.RestoreVerboseStatus(
                    message_type = '', 
                    action = '', 
                    item = '', 
                    size = 56, ),
                restoration_error = cybee_sdk.api.models.restoration_error.RestorationError(
                    error = '', 
                    during = '', 
                    item = '', ),
                summary = cybee_sdk.api.models.restoration_summary.RestorationSummary(
                    seconds_elapsed = 56, 
                    total_files = 56, 
                    files_restored = 56, 
                    total_bytes = 56, 
                    bytes_restored = 56, ),
                unknown = '',
                other_error = '',
                restoration_ended = cybee_sdk.api.models.process_ended.ProcessEnded(),
                restoration_fully_finished = cybee_sdk.api.models.operation_fully_finished.OperationFullyFinished(),
                timestamp = ''
            )
        else:
            return RestorationInfo(
                timestamp = '',
        )
        """

    def testRestorationInfo(self):
        """Test RestorationInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Filesystem(BaseModel):
    """
    Filesystem
    """  # noqa: E501

    name: StrictStr
    filesystem: StrictStr
    mount_points: Optional[List[StrictStr]] = None
    total_size: StrictInt
    available_space: Optional[StrictInt] = None
    is_root: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = [
        "name",
        "filesystem",
        "mount_points",
        "total_size",
        "available_space",
        "is_root",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Filesystem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if mount_points (nullable) is None
        # and model_fields_set contains the field
        if self.mount_points is None and "mount_points" in self.model_fields_set:
            _dict["mount_points"] = None

        # set to None if available_space (nullable) is None
        # and model_fields_set contains the field
        if self.available_space is None and "available_space" in self.model_fields_set:
            _dict["available_space"] = None

        # set to None if is_root (nullable) is None
        # and model_fields_set contains the field
        if self.is_root is None and "is_root" in self.model_fields_set:
            _dict["is_root"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Filesystem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "filesystem": obj.get("filesystem"),
                "mount_points": obj.get("mount_points"),
                "total_size": obj.get("total_size"),
                "available_space": obj.get("available_space"),
                "is_root": obj.get("is_root"),
            }
        )
        return _obj
